<?php

namespace Drupal\danse_user\Plugin\Danse;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadInterface;
use Drupal\danse\PluginBase;
use Drupal\danse_user\Payload;

/**
 * Plugin implementation of DANSE.
 *
 * @Danse(
 *   id = "user",
 *   label = @Translation("User"),
 *   description = @Translation("Manages all user events.")
 * )
 */
class User extends PluginBase {

  public const TOPIC_CREATE = 'create';

  public const TOPIC_UPDATE = 'update';

  public const TOPIC_CANCEL = 'cancel';

  public const TOPIC_LOGIN = 'login';

  public const TOPIC_LOGOUT = 'logout';

  /**
   * {@inheritdoc}
   */
  public function assertPayload(PayloadInterface $payload): bool {
    return $payload instanceof Payload;
  }

  /**
   * {@inheritdoc}
   */
  public function getSupportedSubscriptions($roles): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(&$form, FormStateInterface $form_state) {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getRedirectUrl(EventInterface $event): Url {
    return Url::fromRoute('<front>');
  }

  public function createUserEvent(string $topic, AccountInterface $account): EventInterface {
    $message = $account->getDisplayName();
    $payload = new Payload($account);
    return $this->createEvent($topic, $message, $payload);
  }

}
