<?php

namespace Drupal\danse_user;

use Drupal;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\danse\Entity\Event;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;
use Drupal\user\Entity\User;

/**
 * Class Payload.
 *
 * @package Drupal\danse_user
 */
final class Payload extends PayloadBase {

  /**
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * Content constructor.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   */
  public function __construct(AccountInterface $account) {
    $this->account = $account;
  }

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    return $this->account->getDisplayName();
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return implode('-', ['user', $this->account->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    return [implode('-', ['user', $event->getTopic()])];
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [
      'account' => $this->account->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): PayloadInterface {
    /** @var \Drupal\user\UserInterface $user */
    $user = User::load($payload['account']);
    return new static($user);
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    /** @var Event $entity */
    $entity = Event::create([
      'plugin' => 'user',
      'topic' => '',
      'label' => '',
      'payload' => $this,
      'push' => TRUE,
      'force' => FALSE,
      'silent' => FALSE,
    ]);
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess($uid): bool {
    return FALSE;
  }

}
